@@ -1,7 +1,5 @@
-import os
 from typing import BinaryIO, TypeVar, Any
 from warnings import warn
-from importlib.util import spec_from_file_location, module_from_spec
 
 from delimited_protobuf import read as _read_delimited
 from google.protobuf import descriptor_pool as _descriptor_pool
@@ -11,29 +9,11 @@ from google.protobuf.message_factory import GetMessageClass
 from . import file_reader
 from .record import Record, FrameSample, MarkerSample, RawSample, LslSample, LslOpenStream, LslCloseStream, \
     RecordMetadata, RecorderVersion
-from .samples import packed_sample_pb2, record_pb2
+from .samples import packed_sample_pb2, record_pb2, default_descriptor_pool
 from .samples.common import marker_pb2
 from .samples.lsl import lsl_stream_pb2
 from .samples.unity import frame_pb2
 
-
-def build_descriptor_pool(root_folder):
-    """
-    Import all generated *_pb2.py modules dynamically.
-    """
-    for root, dirs, files in os.walk(root_folder):
-        for file in files:
-            if file.endswith("_pb2.py"):
-                # Dynamically import the module
-                module_name = file[:-6]  # Remove "_pb2.py" from the file name
-                spec = spec_from_file_location(module_name, os.path.join(root, file))
-                module = module_from_spec(spec)
-                spec.loader.exec_module(module)
-    return _descriptor_pool.Default()
-
-
-__default_descriptor_pool = build_descriptor_pool(os.path.dirname(__file__))
-
 T = TypeVar('T', bound=Message)
 
 
@@ -132,7 +112,7 @@ def parse_raw_lsl_close_streams(raw_lsl_close_streams: list[RawSample[lsl_stream
 
 
 def parse_raw_frame_sample(raw_frame_sample: RawSample[frame_pb2.Frame],
-                           descriptor_pool: _descriptor_pool.DescriptorPool = __default_descriptor_pool) -> FrameSample:
+                           descriptor_pool: _descriptor_pool.DescriptorPool = default_descriptor_pool) -> FrameSample:
     """Unpacks a sample containing a payload of type Frame into a list of unpacked frame data samples."""
     packed_frame: frame_pb2.Frame = raw_frame_sample.payload
     frame_data_samples: list[RawSample] = []
@@ -147,7 +127,7 @@ def parse_raw_frame_sample(raw_frame_sample: RawSample[frame_pb2.Frame],
 
 
 def parse_raw_frame_samples(raw_frame_samples: list[RawSample[frame_pb2.Frame]],
-                            descriptor_pool: _descriptor_pool.DescriptorPool = __default_descriptor_pool) -> list[
+                            descriptor_pool: _descriptor_pool.DescriptorPool = default_descriptor_pool) -> list[
     FrameSample]:
     """Unpacks a list of frames into a list of unpacked frame data samples."""
     frame_samples: list[FrameSample] = []
@@ -159,7 +139,7 @@ def parse_raw_frame_samples(raw_frame_samples: list[RawSample[frame_pb2.Frame]],
 
 
 def unpack_sample(packed_sample: packed_sample_pb2.PackedSample,
-                  descriptor_pool: _descriptor_pool.DescriptorPool = __default_descriptor_pool) -> RawSample:
+                  descriptor_pool: _descriptor_pool.DescriptorPool = default_descriptor_pool) -> RawSample:
     """Unpacks the payload of a packed sample using the provided descriptor pool and returns an unpacked sample."""
     unpacked_payload = unpack_any(packed_sample.payload, descriptor_pool)
     if unpacked_payload is None:
@@ -169,7 +149,7 @@ def unpack_sample(packed_sample: packed_sample_pb2.PackedSample,
 
 
 def unpack_samples(packed_samples: list[packed_sample_pb2.PackedSample],
-                   descriptor_pool: _descriptor_pool.DescriptorPool = __default_descriptor_pool) -> list[RawSample]:
+                   descriptor_pool: _descriptor_pool.DescriptorPool = default_descriptor_pool) -> list[RawSample]:
     """Unpacks the payload of each packed samples in the list using the provided descriptor pool and returns a list of unpacked samples."""
     raw_samples: list[RawSample] = []
     for packed_sample in packed_samples:
