@@ -5,7 +5,11 @@ from ..samples.unity.game_object_pb2 import GameObjectUpdate
 from ..samples.unity.identifiers_pb2 import GameObjectIdentifier
 
 
-def find_game_object_identifiers(record: Record, name: str) -> list[GameObjectIdentifier]:
+def find_first_name(record: Record, guid: str) -> Optional[GameObjectUpdate]:
+    pass
+
+
+def find_identifiers(record: Record, name: str) -> list[GameObjectIdentifier]:
     identifiers: list[GameObjectIdentifier] = []
     known_guids: set[str] = set()
 
@@ -20,7 +24,7 @@ def find_game_object_identifiers(record: Record, name: str) -> list[GameObjectId
     return identifiers
 
 
-def find_first_game_object_identifier(record: Record, name: str) -> Optional[GameObjectIdentifier]:
+def find_first_identifier(record: Record, name: str) -> Optional[GameObjectIdentifier]:
     for frame in record.frames:
         for frame_data in frame.data:
             if isinstance(frame_data.payload, GameObjectUpdate):
